@@ -46,5 +46,5 @@ pub fn for_reader<R: std::io::Read>(mut r: R) -> TractResult<InferenceModel> {
 pub fn onnx() -> Onnx {
     let mut ops = crate::model::OnnxOpRegister::default();
     ops::register_all_ops(&mut ops);
-    Onnx { op_register: ops }
+    Onnx { op_register: ops, ..Onnx::default() }
 }
